@@ -36,7 +36,7 @@ namespace DefaultIni {
                "[general]\n"
                "theme=dark\n"
                "dimensions=1366x768\n"
-               "indel_length=10\n"
+               "indel_length=15\n"
                "ylim=50\n"
                "coverage=true\n"
                "log2_cov=false\n"
@@ -47,11 +47,11 @@ namespace DefaultIni {
                "pad=500\n"
                "scroll_speed=0.15\n"
                "tabix_track_height=0.15\n"
-               "font=Menlo\n"
+               "font=Default\n"
                "font_size=14\n"
                "sv_arcs=true\n"
                "mods=false\n"
-               "mods_qual_threshold=50\n"
+               "mods_qual_threshold=150\n"
                "session_file=\n"
                "\n"
                "[view_thresholds]\n"
