@@ -60,6 +60,7 @@ namespace Parse {
         RNEXT = 4003,
         SEQ = 4004,
         RG = 4005, BC = 4006, LB = 4007, MD = 4008, PU = 4010, SA = 4011, MC = 4012, BX = 4013, MI = 4014, RX = 4015,
+        SEQ_RC = 4016,
 
         EQ = -1,
         NE = -2,
@@ -79,6 +80,8 @@ namespace Parse {
         Property property;
         Property op;
         bool result;
+        bool numeric_like{true};
+        bool exists{true};  // Set to false if tag field is missing
         void eval();
     };
 
